@@ -203,7 +203,19 @@ class ActionEnvironmentSecret(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ActionEnvironmentSecret.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                environment: builtins.str,
+                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+                repository: IGitHubRepository,
+                repository_secret_name: builtins.str,
+                source_secret: aws_cdk.aws_secretsmanager.ISecret,
+                source_secret_json_field: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ActionEnvironmentSecretProps(
@@ -252,7 +264,17 @@ class ActionEnvironmentSecretProps:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ActionEnvironmentSecretProps.__init__)
+            def stub(
+                *,
+                environment: builtins.str,
+                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+                repository: IGitHubRepository,
+                repository_secret_name: builtins.str,
+                source_secret: aws_cdk.aws_secretsmanager.ISecret,
+                source_secret_json_field: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
             check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
@@ -376,7 +398,18 @@ class ActionSecret(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ActionSecret.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+                repository: IGitHubRepository,
+                repository_secret_name: builtins.str,
+                source_secret: aws_cdk.aws_secretsmanager.ISecret,
+                source_secret_json_field: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ActionSecretProps(
@@ -421,7 +454,16 @@ class ActionSecretProps:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ActionSecretProps.__init__)
+            def stub(
+                *,
+                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+                repository: IGitHubRepository,
+                repository_secret_name: builtins.str,
+                source_secret: aws_cdk.aws_secretsmanager.ISecret,
+                source_secret_json_field: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
             check_type(argname="argument repository_secret_name", value=repository_secret_name, expected_type=type_hints["repository_secret_name"])
@@ -541,7 +583,22 @@ class GitHubResource(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitHubResource.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                create_request_endpoint: builtins.str,
+                delete_request_endpoint: builtins.str,
+                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+                create_request_payload: typing.Optional[builtins.str] = None,
+                create_request_result_parameter: typing.Optional[builtins.str] = None,
+                delete_request_payload: typing.Optional[builtins.str] = None,
+                update_request_endpoint: typing.Optional[builtins.str] = None,
+                update_request_payload: typing.Optional[builtins.str] = None,
+                write_response_to_ssm_parameter: typing.Optional[aws_cdk.aws_ssm.IParameter] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitHubResourceProps(
@@ -602,7 +659,20 @@ class GitHubResourceProps:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(GitHubResourceProps.__init__)
+            def stub(
+                *,
+                create_request_endpoint: builtins.str,
+                delete_request_endpoint: builtins.str,
+                github_token_secret: aws_cdk.aws_secretsmanager.ISecret,
+                create_request_payload: typing.Optional[builtins.str] = None,
+                create_request_result_parameter: typing.Optional[builtins.str] = None,
+                delete_request_payload: typing.Optional[builtins.str] = None,
+                update_request_endpoint: typing.Optional[builtins.str] = None,
+                update_request_payload: typing.Optional[builtins.str] = None,
+                write_response_to_ssm_parameter: typing.Optional[aws_cdk.aws_ssm.IParameter] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument create_request_endpoint", value=create_request_endpoint, expected_type=type_hints["create_request_endpoint"])
             check_type(argname="argument delete_request_endpoint", value=delete_request_endpoint, expected_type=type_hints["delete_request_endpoint"])
             check_type(argname="argument github_token_secret", value=github_token_secret, expected_type=type_hints["github_token_secret"])
@@ -833,7 +903,9 @@ class _IGitHubRepositoryProxy:
     @name.setter
     def name(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IGitHubRepository, "name").fset)
+            def stub(value: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "name", value)
 
@@ -851,7 +923,9 @@ class _IGitHubRepositoryProxy:
     @owner.setter
     def owner(self, value: typing.Optional[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(IGitHubRepository, "owner").fset)
+            def stub(value: typing.Optional[builtins.str]) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "owner", value)
 
